import { Component, Input, ElementRef, Renderer, ChangeDetectionStrategy } from '@angular/core';
import { WindowService } from '../window/window.service';
export var Disqus = (function () {
    function Disqus(el, renderer, window) {
        this.el = el;
        this.renderer = renderer;
        this.window = window.nativeWindow;
    }
    Disqus.prototype.ngAfterViewInit = function () {
        if (this.window.DISQUS === undefined) {
            this.addScriptTag();
        }
        else {
            this.reset();
        }
    };
    /**
     * Reset disqus with new inputs.
     */
    Disqus.prototype.reset = function () {
        this.window.DISQUS.reset({
            reload: true,
            config: this.getConfig()
        });
    };
    /**
     * Add disqus script to the document.
     */
    Disqus.prototype.addScriptTag = function () {
        this.window.disqus_config = this.getConfig();
        var script = this.renderer.createElement(this.el.nativeElement, 'script');
        script.src = "//" + this.shortname + ".disqus.com/embed.js";
        script.async = true;
        script.type = 'text/javascript';
        script.setAttribute('data-timestamp', new Date().getTime().toString());
    };
    /**
     * Get disqus config
     */
    Disqus.prototype.getConfig = function () {
        var _self = this;
        return function () {
            this.page.url = this.url || this.window.location.href;
            this.page.identifier = _self.identifier;
            this.page.category_id = this.categoryId;
            this.language = this.lang;
        };
    };
    Disqus.prototype.ngOnDestroy = function () {
        if (this.removeOnDestroy) {
            this.window.DISQUS = undefined;
        }
    };
    Disqus.decorators = [
        { type: Component, args: [{
                    selector: 'disqus',
                    template: '<div id="disqus_thread"></div>',
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    Disqus.ctorParameters = [
        { type: ElementRef, },
        { type: Renderer, },
        { type: WindowService, },
    ];
    Disqus.propDecorators = {
        'identifier': [{ type: Input },],
        'shortname': [{ type: Input },],
        'url': [{ type: Input },],
        'categoryId': [{ type: Input },],
        'lang': [{ type: Input },],
        'removeOnDestroy': [{ type: Input },],
    };
    return Disqus;
}());
//# sourceMappingURL=disqus.component.js.map